OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "您已為您的帳號啟用了 TOTP 兩階段驗證",
    "You disabled TOTP two-factor authentication for your account" : "您已為您的帳號停用了 TOTP 兩階段驗證",
    "TOTP two-factor authentication disabled by the administration" : "管理員已停用 TOTP 兩階段身份驗證",
    "TOTP (Authenticator app)" : "TOTP（驗證應用程式）",
    "Authenticate with a TOTP app" : "使用 TOTP 應用程式驗證身分",
    "Two-Factor TOTP Provider" : "雙因驗證 TOTP 碼提供者",
    "Two-factor TOTP provider" : "兩階段 TOTP 提供者",
    "A two-factor authentication provider for TOTP (RFC 6238)" : "TOTP 兩階段驗證提供者 (RFC 6238)",
    "Enable TOTP" : "啟用 TOTP",
    "Could not enable TOTP" : "無法啟用 TOTP",
    "Could not verify your key. Please try again" : "無法驗證您的金鑰。請重試",
    "Your new TOTP secret is:" : "您的新 TOTP 密鑰為：",
    "For quick setup, scan this QR code with your TOTP app:" : "使用您的 TOTP 應用程式掃描此 QR code 可快速設定：",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "當你設定好你的應用程式，請試著在下方輸入應用程式產生的驗證碼，以確保一切正常運作。",
    "Authentication code" : "驗證碼",
    "Verify" : "核對",
    "Get the authentication code from the two-factor authentication app on your device." : "從您裝置上的兩階段驗證應用程式取得驗證碼。",
    "Submit" : "送出",
    "TOTP two-factor authentication disabled by an admin" : "TOTP 兩階段驗證功能已被系統管理員停用",
    "TOTP two-factor provider" : "TOTP 兩階段驗證提供者",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "TOTP 兩階段驗證裝置提供者 (RFC 6238)"
},
"nplurals=1; plural=0;");
